pub enum OverpassError {
Query(OverpassQLError),
Request(Error),
Parse(Error),
Other(String),
}Expand description
An error returned when a request to evaluate a Query fails.
Variants
Query(OverpassQLError)
There was an error serializing the query.
Request(Error)
There was an error communicating with the Overpass server.
Parse(Error)
There was an error parsing the response from the Overpass server.
Other(String)
An unknown error occurred.