pub enum OverpassQLError {
Format,
CircularReference,
}Expand description
An error returned when a Query cannot produce a valid OverpassQL query string.
Variants
Format
Failed to write to the string.
CircularReference
This query contains sets with mutual dependencies, making evaluation impossible.