pub enum RecurseFilter<'a> {
WithinWays {
input: Cow<'a, Set<'a>>,
},
WithinRelations {
input: Cow<'a, Set<'a>>,
role: Option<SaniStr<'a>>,
},
ContainingNodes {
input: Cow<'a, Set<'a>>,
role: Option<SaniStr<'a>>,
},
ContainingWays {
input: Cow<'a, Set<'a>>,
role: Option<SaniStr<'a>>,
},
ContainingRelations {
input: Cow<'a, Set<'a>>,
role: Option<SaniStr<'a>>,
},
}Expand description
A filter set criterion based on the element’s relationship to other elements.
Variants
WithinWays
WithinRelations
Select Nodes/Ways that are members of a Relation in the provided input Set. If a role is specified, the element must also have that role in said relations.
ContainingNodes
Select Ways/Relations that have a member Node in the provided input Set. If a role is specified, the node must also have that role in said relations.
ContainingWays
Select Relations that have a member Way in the provided input Set. If a role is specified, the way must also have that role in said relations.
ContainingRelations
Implementations