pub struct Bbox {
pub south: f64,
pub west: f64,
pub north: f64,
pub east: f64,
}Expand description
A geographic bounding box defined by two latitudes and two longitudes. Used to distinguish points inside and outside the box.
Fields
south: f64The latitude of the southern edge of the bounding box.
west: f64The longitude of the western edge of the bounding box.
north: f64The latitude of the northern edge of the bounding box.
east: f64The longitude of the eastern edge of the bounding box.
Implementations