SetBuilder

Struct SetBuilder 

pub struct SetBuilder;
Provides methods to build all the various types of OverpassQL Sets.

Implementations

Source

impl SetBuilder

Methods to create new FilterSets.

pub fn all_nodes<'a>() -> FilterSetBuilder<'a>

Start a new filter set containing Nodes, i.e. FilterType::Node.

pub fn nodes_from<'a, T>( sets: impl IntoIterator<Item = T>, ) -> FilterSetBuilder<'a>
where T: Into<Cow<'a, Set<'a>>>,

Start a new filter set containing the Nodes common to all provided sets. See FilterSet::inputs.

pub fn all_ways<'a>() -> FilterSetBuilder<'a>

Start a new filter set containing Ways, i.e. FilterType::Way.

pub fn ways_from<'a, T>( sets: impl IntoIterator<Item = T>, ) -> FilterSetBuilder<'a>
where T: Into<Cow<'a, Set<'a>>>,

Start a new filter set containing the Ways common to all provided sets. See FilterSet::inputs.

pub fn all_relations<'a>() -> FilterSetBuilder<'a>

Start a new filter set containing Relations, i.e. FilterType::Relation.

pub fn relations_from<'a, T>( sets: impl IntoIterator<Item = T>, ) -> FilterSetBuilder<'a>
where T: Into<Cow<'a, Set<'a>>>,

Start a new filter set containing the Relations common to all provided sets. See FilterSet::inputs.

pub fn any_type<'a>() -> FilterSetBuilder<'a>

Start a new filter set containing any element type, i.e. FilterType::Any.

pub fn any_from<'a, T>( sets: impl IntoIterator<Item = T>, ) -> FilterSetBuilder<'a>
where T: Into<Cow<'a, Set<'a>>>,

Start a new filter set containing the elements common to all provided sets. See FilterSet::inputs.

pub fn all_nodes_or_ways<'a>() -> FilterSetBuilder<'a>

Start a new filter set containing Nodes or Ways, i.e. FilterType::NodeOrWay.

pub fn nodes_or_ways_from<'a, T>( sets: impl IntoIterator<Item = T>, ) -> FilterSetBuilder<'a>
where T: Into<Cow<'a, Set<'a>>>,

Start a new filter set containing Nodes and Ways common to all provided sets. See FilterSet::inputs.

pub fn all_nodes_or_relations<'a>() -> FilterSetBuilder<'a>

Start a new filter set containing Nodes or Relations, i.e. FilterType::NodeOrRelation.

pub fn nodes_or_relations_from<'a, T>( sets: impl IntoIterator<Item = T>, ) -> FilterSetBuilder<'a>
where T: Into<Cow<'a, Set<'a>>>,

Start a new filter set containing the Nodes and Relations common to all provided sets. See FilterSet::inputs.

pub fn all_ways_or_relations<'a>() -> FilterSetBuilder<'a>

Start a new filter set containing Ways or Relations, i.e. FilterType::WayOrRelation.

pub fn ways_or_relations_from<'a, T>( sets: impl IntoIterator<Item = T>, ) -> FilterSetBuilder<'a>
where T: Into<Cow<'a, Set<'a>>>,

Start a new filter set containing the Ways and Relations common to all provided sets. See FilterSet::inputs.

pub fn all_areas<'a>() -> FilterSetBuilder<'a>

Start a new filter set containing elements identified as areas, i.e. FilterType::Area.

pub fn areas_from<'a, T>( sets: impl IntoIterator<Item = T>, ) -> FilterSetBuilder<'a>
where T: Into<Cow<'a, Set<'a>>>,

Start a new filter set containing the Area elements common to all provided sets. See FilterSet::inputs.

Source

impl SetBuilder

pub fn union<'a, T>(sets: impl IntoIterator<Item = T>) -> UnionSetBuilder<'a>
where T: Into<Cow<'a, Set<'a>>>,

Collect the provided sets into a new UnionSet