pub struct UnionSet<'a>(pub HashSet<Cow<'a, Set<'a>>>);Expand description
A Set that is composed of all elements found in any member set.
Tuple Fields
0: HashSet<Cow<'a, Set<'a>>>The collection of sets whose contents make up this set.
Implementations