OverpassQL

Trait OverpassQL 

pub trait OverpassQL {
    // Required method
    fn fmt_oql(&self, f: &mut impl Write) -> Result<(), OverpassQLError>;

    // Provided method
    fn to_oql(&self) -> String { ... }
}
Implementers can be represented as a full or partial OverpassQL query.

Required Methods

fn fmt_oql(&self, f: &mut impl Write) -> Result<(), OverpassQLError>

Write the OverpassQL representation to the given Write object.

Provided Methods

fn to_oql(&self) -> String

Write the OverpassQL representation into a String, panicking if the conversion fails.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors