pub struct FilterSet<'a> {
pub filter_type: FilterType,
pub inputs: HashSet<Cow<'a, Set<'a>>>,
pub id_filters: HashSet<i64>,
pub tag_filters: HashSet<TagFilter<'a>>,
pub bbox_filter: Option<Bbox>,
pub recurse_filters: HashSet<RecurseFilter<'a>>,
}Expand description
A subtype of Set that contains elements that satisfy the specified criteria.
Fields
filter_type: FilterTypeThe type(s) of elements eligible to be in this set. wiki
inputs: HashSet<Cow<'a, Set<'a>>>Only elements common to all of these sets are eligible to be in this set. An empty collection means all elements are eligible. wiki
id_filters: HashSet<i64>Only elements with one of these identifiers are eligible to be in this set. An empty collection means identifiers are not considered. wiki
tag_filters: HashSet<TagFilter<'a>>Only elements whose tags satisfy all these filters are eligible to be in this set. wiki
bbox_filter: Option<Bbox>Only elements that lie within these bounds are eligible to be in this set. wiki
recurse_filters: HashSet<RecurseFilter<'a>>Only elements with these relationships are eligible to be in this set. wiki
Implementations