pub struct Query<'a> {
pub timeout_s: Option<u32>,
pub max_size: Option<u32>,
pub search_bbox: Option<Bbox>,
pub as_of_date: Option<DateTime<Utc>>,
pub diff: Option<(DateTime<Utc>, Option<DateTime<Utc>>)>,
pub verbosity: QueryVerbosity,
pub set: Set<'a>,
}Expand description
The root type of this API. It serializes into a complete Overpass QL query by calling to_oql.
Fields
timeout_s: Option<u32>The length of time in seconds after which the server will abort the query. wiki
max_size: Option<u32>The maximum allowed memory for the query in bytes RAM on the server, beyond which the server will abort the query. wiki
search_bbox: Option<Bbox>Apply the query only to elements within the region defined by the bounding box. wiki
as_of_date: Option<DateTime<Utc>>Query the state of the map as of the given date/time. wiki
diff: Option<(DateTime<Utc>, Option<DateTime<Utc>>)>Query only elements created/modified between the first date/time, and the second date/time if supplied, or now if not. wiki
verbosity: QueryVerbosityset: Set<'a>Trait Implementations
Sourceimpl<'a> AsRef<Query<'a>> for QueryBuilder<'a>
impl<'a> AsRef<Query<'a>> for QueryBuilder<'a>
Sourceimpl<'a> Into<Query<'a>> for QueryBuilder<'a>
impl<'a> Into<Query<'a>> for QueryBuilder<'a>