pub struct SetBuilder;Expand description
Provides methods to build all the various types of OverpassQL Sets.
Implementations
Sourceimpl SetBuilder
Methods to create new FilterSets.
impl SetBuilder
Methods to create new FilterSets.
Sourcepub fn all_nodes<'a>() -> FilterSetBuilder<'a>
pub fn all_nodes<'a>() -> FilterSetBuilder<'a>
Start a new filter set containing Nodes, i.e. FilterType::Node.
Sourcepub fn nodes_from<'a, T>(
sets: impl IntoIterator<Item = T>,
) -> FilterSetBuilder<'a>
pub fn nodes_from<'a, T>( sets: impl IntoIterator<Item = T>, ) -> FilterSetBuilder<'a>
Start a new filter set containing the Nodes common to all provided sets. See FilterSet::inputs.
Sourcepub fn all_ways<'a>() -> FilterSetBuilder<'a>
pub fn all_ways<'a>() -> FilterSetBuilder<'a>
Start a new filter set containing Ways, i.e. FilterType::Way.
Sourcepub fn ways_from<'a, T>(
sets: impl IntoIterator<Item = T>,
) -> FilterSetBuilder<'a>
pub fn ways_from<'a, T>( sets: impl IntoIterator<Item = T>, ) -> FilterSetBuilder<'a>
Start a new filter set containing the Ways common to all provided sets. See FilterSet::inputs.
Sourcepub fn all_relations<'a>() -> FilterSetBuilder<'a>
pub fn all_relations<'a>() -> FilterSetBuilder<'a>
Start a new filter set containing Relations, i.e. FilterType::Relation.
Sourcepub fn relations_from<'a, T>(
sets: impl IntoIterator<Item = T>,
) -> FilterSetBuilder<'a>
pub fn relations_from<'a, T>( sets: impl IntoIterator<Item = T>, ) -> FilterSetBuilder<'a>
Start a new filter set containing the Relations common to all provided sets. See FilterSet::inputs.
Sourcepub fn any_type<'a>() -> FilterSetBuilder<'a>
pub fn any_type<'a>() -> FilterSetBuilder<'a>
Start a new filter set containing any element type, i.e. FilterType::Any.
Sourcepub fn any_from<'a, T>(
sets: impl IntoIterator<Item = T>,
) -> FilterSetBuilder<'a>
pub fn any_from<'a, T>( sets: impl IntoIterator<Item = T>, ) -> FilterSetBuilder<'a>
Start a new filter set containing the elements common to all provided sets. See FilterSet::inputs.
Sourcepub fn all_nodes_or_ways<'a>() -> FilterSetBuilder<'a>
pub fn all_nodes_or_ways<'a>() -> FilterSetBuilder<'a>
Start a new filter set containing Nodes or Ways, i.e. FilterType::NodeOrWay.
Sourcepub fn nodes_or_ways_from<'a, T>(
sets: impl IntoIterator<Item = T>,
) -> FilterSetBuilder<'a>
pub fn nodes_or_ways_from<'a, T>( sets: impl IntoIterator<Item = T>, ) -> FilterSetBuilder<'a>
Start a new filter set containing Nodes and Ways common to all provided sets. See FilterSet::inputs.
Sourcepub fn all_nodes_or_relations<'a>() -> FilterSetBuilder<'a>
pub fn all_nodes_or_relations<'a>() -> FilterSetBuilder<'a>
Start a new filter set containing Nodes or Relations, i.e. FilterType::NodeOrRelation.
Sourcepub fn nodes_or_relations_from<'a, T>(
sets: impl IntoIterator<Item = T>,
) -> FilterSetBuilder<'a>
pub fn nodes_or_relations_from<'a, T>( sets: impl IntoIterator<Item = T>, ) -> FilterSetBuilder<'a>
Start a new filter set containing the Nodes and Relations common to all provided sets. See FilterSet::inputs.
Sourcepub fn all_ways_or_relations<'a>() -> FilterSetBuilder<'a>
pub fn all_ways_or_relations<'a>() -> FilterSetBuilder<'a>
Start a new filter set containing Ways or Relations, i.e. FilterType::WayOrRelation.
Sourcepub fn ways_or_relations_from<'a, T>(
sets: impl IntoIterator<Item = T>,
) -> FilterSetBuilder<'a>
pub fn ways_or_relations_from<'a, T>( sets: impl IntoIterator<Item = T>, ) -> FilterSetBuilder<'a>
Start a new filter set containing the Ways and Relations common to all provided sets. See FilterSet::inputs.
Sourcepub fn all_areas<'a>() -> FilterSetBuilder<'a>
pub fn all_areas<'a>() -> FilterSetBuilder<'a>
Start a new filter set containing elements identified as areas, i.e. FilterType::Area.
Sourcepub fn areas_from<'a, T>(
sets: impl IntoIterator<Item = T>,
) -> FilterSetBuilder<'a>
pub fn areas_from<'a, T>( sets: impl IntoIterator<Item = T>, ) -> FilterSetBuilder<'a>
Start a new filter set containing the Area elements common to all provided sets. See FilterSet::inputs.
Sourceimpl SetBuilder
impl SetBuilder
Sourcepub fn union<'a, T>(sets: impl IntoIterator<Item = T>) -> UnionSetBuilder<'a>
pub fn union<'a, T>(sets: impl IntoIterator<Item = T>) -> UnionSetBuilder<'a>
Collect the provided sets into a new UnionSet